Kreuzberg.Application (kreuzberg v4.4.5)

Copy Markdown View Source

OTP Application callback for Kreuzberg.

This module defines the application supervision tree, which starts all the necessary services for the Kreuzberg library.