Kreuzberg.Application (kreuzberg v4.0.8)

OTP Application callback for Kreuzberg.

This module defines the application supervision tree, which starts all the necessary services for the Kreuzberg library.